unified_diff_string

Function unified_diff_string 

pub fn unified_diff_string(diff: &FileDiff, opts: &UnifiedDiffOptions) -> String
Render a FileDiff as a unified-diff string. Identical layout to git diff so agents and humans both find this reading exactly as they expect. Empty string for unchanged files.